@@ -25,8 +25,6 @@
 #include <glib/gi18n.h>
 #include <packagekit-glib2/packagekit.h>
 
-#include "egg-string.h"
-
 #include "gpk-enum.h"
 #include "gpk-common.h"
 
@@ -187,9 +185,6 @@ static const PkEnumMatch enum_restart_icon_name[] = {
 	{0, NULL}
 };
 
-/**
- * gpk_media_type_enum_to_localised_text:
- **/
 const gchar *
 gpk_media_type_enum_to_localised_text (PkMediaTypeEnum type)
 {
@@ -217,9 +212,6 @@ gpk_media_type_enum_to_localised_text (PkMediaTypeEnum type)
 	return text;
 }
 
-/**
- * gpk_error_enum_to_localised_text:
- **/
 const gchar *
 gpk_error_enum_to_localised_text (PkErrorEnum code)
 {
@@ -435,9 +427,6 @@ gpk_error_enum_to_localised_text (PkErrorEnum code)
 	return text;
 }
 
-/**
- * gpk_error_enum_to_localised_message:
- **/
 const gchar *
 gpk_error_enum_to_localised_message (PkErrorEnum code)
 {
@@ -692,9 +681,6 @@ gpk_error_enum_to_localised_message (PkErrorEnum code)
 	return text;
 }
 
-/**
- * gpk_restart_enum_to_localised_text_future:
- **/
 const gchar *
 gpk_restart_enum_to_localised_text_future (PkRestartEnum restart)
 {
@@ -724,9 +710,6 @@ gpk_restart_enum_to_localised_text_future (PkRestartEnum restart)
 	return text;
 }
 
-/**
- * gpk_restart_enum_to_localised_text:
- **/
 const gchar *
 gpk_restart_enum_to_localised_text (PkRestartEnum restart)
 {
@@ -756,9 +739,6 @@ gpk_restart_enum_to_localised_text (PkRestartEnum restart)
 	return text;
 }
 
-/**
- * gpk_status_enum_to_localised_text:
- **/
 const gchar *
 gpk_status_enum_to_localised_text (PkStatusEnum status)
 {
@@ -914,9 +894,6 @@ gpk_status_enum_to_localised_text (PkStatusEnum status)
 	return text;
 }
 
-/**
- * gpk_info_enum_to_localised_text:
- **/
 const gchar *
 gpk_info_enum_to_localised_text (PkInfoEnum info)
 {
@@ -974,9 +951,6 @@ gpk_info_enum_to_localised_text (PkInfoEnum info)
 	return text;
 }
 
-/**
- * gpk_info_enum_to_localised_present:
- **/
 static const gchar *
 gpk_info_enum_to_localised_present (PkInfoEnum info)
 {
@@ -1024,9 +998,6 @@ gpk_info_enum_to_localised_present (PkInfoEnum info)
 	return text;
 }
 
-/**
- * gpk_info_enum_to_localised_past:
- **/
 const gchar *
 gpk_info_enum_to_localised_past (PkInfoEnum info)
 {
@@ -1074,151 +1045,6 @@ gpk_info_enum_to_localised_past (PkInfoEnum info)
 	return text;
 }
 
-/**
- * gpk_role_enum_to_localised_present:
- **/
-const gchar *
-gpk_role_enum_to_localised_present (PkRoleEnum role)
-{
-	const gchar *text = NULL;
-	switch (role) {
-	case PK_ROLE_ENUM_UNKNOWN:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Unknown role type");
-		break;
-	case PK_ROLE_ENUM_DEPENDS_ON:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting dependencies");
-		break;
-	case PK_ROLE_ENUM_GET_UPDATE_DETAIL:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting update detail");
-		break;
-	case PK_ROLE_ENUM_GET_DETAILS:
-	case PK_ROLE_ENUM_GET_DETAILS_LOCAL:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting details");
-		break;
-	case PK_ROLE_ENUM_REQUIRED_BY:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting requires");
-		break;
-	case PK_ROLE_ENUM_GET_UPDATES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting updates");
-		break;
-	case PK_ROLE_ENUM_SEARCH_DETAILS:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Searching details");
-		break;
-	case PK_ROLE_ENUM_SEARCH_FILE:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Searching for file");
-		break;
-	case PK_ROLE_ENUM_SEARCH_GROUP:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Searching groups");
-		break;
-	case PK_ROLE_ENUM_SEARCH_NAME:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Searching for package name");
-		break;
-	case PK_ROLE_ENUM_REMOVE_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Removing");
-		break;
-	case PK_ROLE_ENUM_INSTALL_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Installing");
-		break;
-	case PK_ROLE_ENUM_INSTALL_FILES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Installing file");
-		break;
-	case PK_ROLE_ENUM_REFRESH_CACHE:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Refreshing package cache");
-		break;
-	case PK_ROLE_ENUM_UPDATE_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Updating packages");
-		break;
-	case PK_ROLE_ENUM_CANCEL:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Canceling");
-		break;
-	case PK_ROLE_ENUM_GET_REPO_LIST:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting list of repositories");
-		break;
-	case PK_ROLE_ENUM_REPO_ENABLE:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Enabling repository");
-		break;
-	case PK_ROLE_ENUM_REPO_REMOVE:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Removing repository");
-		break;
-	case PK_ROLE_ENUM_REPO_SET_DATA:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Setting repository data");
-		break;
-	case PK_ROLE_ENUM_RESOLVE:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Resolving");
-		break;
-	case PK_ROLE_ENUM_GET_FILES:
-	case PK_ROLE_ENUM_GET_FILES_LOCAL:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting file list");
-		break;
-	case PK_ROLE_ENUM_WHAT_PROVIDES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting what provides");
-		break;
-	case PK_ROLE_ENUM_INSTALL_SIGNATURE:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Installing signature");
-		break;
-	case PK_ROLE_ENUM_GET_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting package lists");
-		break;
-	case PK_ROLE_ENUM_ACCEPT_EULA:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Accepting EULA");
-		break;
-	case PK_ROLE_ENUM_DOWNLOAD_PACKAGES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Downloading packages");
-		break;
-	case PK_ROLE_ENUM_GET_DISTRO_UPGRADES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting distribution upgrade information");
-		break;
-	case PK_ROLE_ENUM_GET_CATEGORIES:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting categories");
-		break;
-	case PK_ROLE_ENUM_GET_OLD_TRANSACTIONS:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Getting old transactions");
-		break;
-	case PK_ROLE_ENUM_REPAIR_SYSTEM:
-		/* TRANSLATORS: The role of the transaction, in present tense */
-		text = _("Repairing the system");
-		break;
-	default:
-		g_warning ("role unrecognized: %s", pk_role_enum_to_string (role));
-	}
-	return text;
-}
-
-/**
- * gpk_role_enum_to_localised_past:
- *
- * These are past tense versions of the action
- **/
 const gchar *
 gpk_role_enum_to_localised_past (PkRoleEnum role)
 {
@@ -1356,9 +1182,6 @@ gpk_role_enum_to_localised_past (PkRoleEnum role)
 	return text;
 }
 
-/**
- * gpk_group_enum_to_localised_text:
- **/
 const gchar *
 gpk_group_enum_to_localised_text (PkGroupEnum group)
 {
@@ -1510,45 +1333,30 @@ gpk_group_enum_to_localised_text (PkGroupEnum group)
 	return text;
 }
 
-/**
- * gpk_info_enum_to_icon_name:
- **/
 const gchar *
 gpk_info_enum_to_icon_name (PkInfoEnum info)
 {
 	return pk_enum_find_string (enum_info_icon_name, info);
 }
 
-/**
- * gpk_status_enum_to_icon_name:
- **/
 const gchar *
 gpk_status_enum_to_icon_name (PkStatusEnum status)
 {
 	return pk_enum_find_string (enum_status_icon_name, status);
 }
 
-/**
- * gpk_role_enum_to_icon_name:
- **/
 const gchar *
 gpk_role_enum_to_icon_name (PkRoleEnum role)
 {
 	return pk_enum_find_string (enum_role_icon_name, role);
 }
 
-/**
- * gpk_group_enum_to_icon_name:
- **/
 const gchar *
 gpk_group_enum_to_icon_name (PkGroupEnum group)
 {
 	return pk_enum_find_string (enum_group_icon_name, group);
 }
 
-/**
- * gpk_restart_enum_to_icon_name:
- **/
 const gchar *
 gpk_restart_enum_to_icon_name (PkRestartEnum restart)
 {
@@ -1559,9 +1367,6 @@ gpk_restart_enum_to_icon_name (PkRestartEnum restart)
 	return tmp;
 }
 
-/**
- * gpk_info_status_enum_to_string:
- **/
 const gchar *
 gpk_info_status_enum_to_string (GpkInfoStatusEnum info)
 {
@@ -1570,9 +1375,6 @@ gpk_info_status_enum_to_string (GpkInfoStatusEnum info)
 	return gpk_info_enum_to_localised_present (info);
 }
 
-/**
- * gpk_info_status_enum_to_icon_name:
- **/
 const gchar *
 gpk_info_status_enum_to_icon_name (GpkInfoStatusEnum info)
 {
