@@ -58,9 +58,6 @@ enum
 	GPK_LOG_COLUMN_LAST
 };
 
-/**
- * gpk_log_find_iter_model_cb:
- **/
 static gboolean
 gpk_log_find_iter_model_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, const gchar *id)
 {
@@ -73,9 +70,6 @@ gpk_log_find_iter_model_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter
 	return FALSE;
 }
 
-/**
- * gpk_log_mark_nonactive_cb:
- **/
 static gboolean
 gpk_log_mark_nonactive_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gpointer data)
 {
@@ -83,18 +77,12 @@ gpk_log_mark_nonactive_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *
 	return FALSE;
 }
 
-/**
- * gpk_log_mark_nonactive:
- **/
 static void
 gpk_log_mark_nonactive (GtkTreeModel *model)
 {
 	gtk_tree_model_foreach (model, (GtkTreeModelForeachFunc) gpk_log_mark_nonactive_cb, NULL);
 }
 
-/**
- * gpk_log_remove_nonactive_cb:
- **/
 static gboolean
 gpk_log_remove_nonactive_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter *iter, gboolean *ret)
 {
@@ -108,9 +96,6 @@ gpk_log_remove_nonactive_cb (GtkTreeModel *model, GtkTreePath *path, GtkTreeIter
 	return FALSE;
 }
 
-/**
- * gpk_log_remove_nonactive:
- **/
 static void
 gpk_log_remove_nonactive (GtkTreeModel *model)
 {
@@ -122,9 +107,6 @@ gpk_log_remove_nonactive (GtkTreeModel *model)
 	} while (ret);
 }
 
-/**
- * gpk_log_model_get_iter:
- **/
 static gboolean
 gpk_log_model_get_iter (GtkTreeModel *model, GtkTreeIter *iter, const gchar *id)
 {
@@ -140,9 +122,6 @@ gpk_log_model_get_iter (GtkTreeModel *model, GtkTreeIter *iter, const gchar *id)
 	return ret;
 }
 
-/**
- * gpk_log_get_localised_date:
- **/
 static gchar *
 gpk_log_get_localised_date (const gchar *timespec)
 {
@@ -164,9 +143,6 @@ gpk_log_get_localised_date (const gchar *timespec)
 	return g_strdup (buffer);
 }
 
-/**
- * gpk_log_get_type_line:
- **/
 static gchar *
 gpk_log_get_type_line (gchar **array, PkInfoEnum info)
 {
@@ -175,24 +151,23 @@ gpk_log_get_type_line (gchar **array, PkInfoEnum info)
 	PkInfoEnum info_local;
 	const gchar *info_text;
 	GString *string;
-	gchar *text;
+	g_autofree gchar *text = NULL;
 	gchar *whole;
-	gchar **sections;
 
 	string = g_string_new ("");
 	size = g_strv_length (array);
 	info_text = gpk_info_enum_to_localised_past (info);
 
 	/* find all of this type */
-	for (i=0; i<size; i++) {
+	for (i = 0; i < size; i++) {
+		g_auto(GStrv) sections = NULL;
 		sections = g_strsplit (array[i], "\t", 0);
 		info_local = pk_info_enum_from_string (sections[0]);
 		if (info_local == info) {
-			text = gpk_package_id_format_oneline (sections[1], NULL);
-			g_string_append_printf (string, "%s, ", text);
-			g_free (text);
+			g_autofree gchar *str = NULL;
+			str = gpk_package_id_format_oneline (sections[1], NULL);
+			g_string_append_printf (string, "%s, ", str);
 		}
-		g_strfreev (sections);
 	}
 
 	/* nothing, so return NULL */
@@ -207,19 +182,15 @@ gpk_log_get_type_line (gchar **array, PkInfoEnum info)
 	/* add a nice header, and make text italic */
 	text = g_string_free (string, FALSE);
 	whole = g_strdup_printf ("<b>%s</b>: %s\n", info_text, text);
-	g_free (text);
 	return whole;
 }
 
-/**
- * gpk_log_get_details_localised:
- **/
 static gchar *
 gpk_log_get_details_localised (const gchar *timespec, const gchar *data)
 {
 	GString *string;
 	gchar *text;
-	gchar **array;
+	g_auto(GStrv) array = NULL;
 
 	string = g_string_new ("");
 	array = g_strsplit (data, "\n", 0);
@@ -237,7 +208,6 @@ gpk_log_get_details_localised (const gchar *timespec, const gchar *data)
 	if (text != NULL)
 		g_string_append (string, text);
 	g_free (text);
-	g_strfreev (array);
 
 	/* remove last \n */
 	if (string->len > 0)
@@ -246,9 +216,6 @@ gpk_log_get_details_localised (const gchar *timespec, const gchar *data)
 	return g_string_free (string, FALSE);
 }
 
-/**
- * gpk_log_treeview_size_allocate_cb:
- **/
 static void
 gpk_log_treeview_size_allocate_cb (GtkWidget *widget, GtkAllocation *allocation, GtkCellRenderer *cell)
 {
@@ -260,9 +227,6 @@ gpk_log_treeview_size_allocate_cb (GtkWidget *widget, GtkAllocation *allocation,
 	g_object_set (cell, "wrap-width", width - 10, NULL);
 }
 
-/**
- * pk_treeview_add_general_columns:
- **/
 static void
 pk_treeview_add_general_columns (GtkTreeView *treeview)
 {
@@ -329,9 +293,6 @@ pk_treeview_add_general_columns (GtkTreeView *treeview)
 	gtk_tree_view_column_set_sort_column_id (column, GPK_LOG_COLUMN_TOOL);
 }
 
-/**
- * gpk_log_treeview_clicked_cb:
- **/
 static void
 gpk_log_treeview_clicked_cb (GtkTreeSelection *selection, gpointer data)
 {
@@ -352,22 +313,17 @@ gpk_log_treeview_clicked_cb (GtkTreeSelection *selection, gpointer data)
 	}
 }
 
-/**
- * gpk_log_filter:
- **/
 static gboolean
 gpk_log_filter (PkTransactionPast *item)
 {
 	gboolean ret = FALSE;
 	guint i;
 	guint length;
-	gchar **sections;
-	gchar **packages;
-	gchar **split;
-	gchar *tid;
+	g_auto(GStrv) packages = NULL;
+	g_autofree gchar *tid = NULL;
 	gboolean succeeded;
-	gchar *cmdline;
-	gchar *data;
+	g_autofree gchar *cmdline = NULL;
+	g_autofree gchar *data = NULL;
 
 	/* get data */
 	g_object_get (item,
@@ -393,7 +349,9 @@ gpk_log_filter (PkTransactionPast *item)
 	/* look in all the data for the filter string */
 	packages = g_strsplit (data, "\n", 0);
 	length = g_strv_length (packages);
-	for (i=0; i<length; i++) {
+	for (i = 0; i < length; i++) {
+		g_auto(GStrv) split = NULL;
+		g_auto(GStrv) sections = NULL;
 		sections = g_strsplit (packages[i], "\t", 0);
 
 		/* check if type matches filter */
@@ -409,44 +367,32 @@ gpk_log_filter (PkTransactionPast *item)
 		if (split[2] != NULL && g_strrstr (split[2], filter) != NULL)
 			ret = TRUE;
 
-		g_strfreev (split);
-		g_strfreev (sections);
-
 		/* shortcut for speed */
 		if (ret)
 			break;
 	}
-
-	g_free (tid);
-	g_free (cmdline);
-	g_free (data);
-	g_strfreev (packages);
-
 	return ret;
 }
 
-/**
- * gpk_log_add_item
- **/
 static void
 gpk_log_add_item (PkTransactionPast *item)
 {
 	GtkTreeIter iter;
-	gchar *details;
-	gchar *date;
+	g_autofree gchar *details = NULL;
+	g_autofree gchar *date = NULL;
 	const gchar *icon_name;
 	const gchar *role_text;
 	const gchar *username = NULL;
 	const gchar *tool;
 	static guint count;
 	struct passwd *pw;
-	gchar *tid;
-	gchar *timespec;
+	g_autofree gchar *tid = NULL;
+	g_autofree gchar *timespec = NULL;
 	gboolean succeeded;
 	guint duration;
-	gchar *cmdline;
+	g_autofree gchar *cmdline = NULL;
 	guint uid;
-	gchar *data;
+	g_autofree gchar *data = NULL;
 	PkRoleEnum role;
 	GtkTreeView *treeview = GTK_TREE_VIEW (gtk_builder_get_object (builder, "treeview_simple"));
 	GtkTreeModel *model = gtk_tree_view_get_model (treeview);
@@ -521,18 +467,8 @@ gpk_log_add_item (PkTransactionPast *item)
 	if (count++ % 10 == 0)
 		while (gtk_events_pending ())
 			gtk_main_iteration ();
-
-	g_free (tid);
-	g_free (timespec);
-	g_free (cmdline);
-	g_free (data);
-	g_free (details);
-	g_free (date);
 }
 
-/**
- * gpk_log_refilter
- **/
 static void
 gpk_log_refilter (void)
 {
@@ -561,7 +497,7 @@ gpk_log_refilter (void)
 	gpk_log_mark_nonactive (model);
 
 	/* go through the list, adding and removing the items as required */
-	for (i=0; i<transactions->len; i++) {
+	for (i = 0; i < transactions->len; i++) {
 		item = g_ptr_array_index (transactions, i);
 		ret = gpk_log_filter (item);
 		if (ret)
@@ -572,30 +508,26 @@ gpk_log_refilter (void)
 	gpk_log_remove_nonactive (model);
 }
 
-/**
- * gpk_log_get_old_transactions_cb
- **/
 static void
 gpk_log_get_old_transactions_cb (GObject *object, GAsyncResult *res, gpointer user_data)
 {
 //	PkClient *client = PK_CLIENT (object);
-	GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 	PkResults *results = NULL;
-	PkError *error_code = NULL;
+	g_autoptr(PkError) error_code = NULL;
 
 	/* get the results */
 	results = pk_client_generic_finish (client, res, &error);
 	if (results == NULL) {
 		g_warning ("failed to get old transactions: %s", error->message);
-		g_error_free (error);
-		goto out;
+		return;
 	}
 
 	/* check error code */
 	error_code = pk_results_get_error_code (results);
 	if (error_code != NULL) {
 		g_warning ("failed to get old transactions: %s, %s", pk_error_enum_to_string (pk_error_get_code (error_code)), pk_error_get_details (error_code));
-		goto out;
+		return;
 	}
 
 	/* get the list */
@@ -603,16 +535,8 @@ gpk_log_get_old_transactions_cb (GObject *object, GAsyncResult *res, gpointer us
 		g_ptr_array_unref (transactions);
 	transactions = pk_results_get_transaction_array (results);
 	gpk_log_refilter ();
-out:
-	if (error_code != NULL)
-		g_object_unref (error_code);
-	if (results != NULL)
-		g_object_unref (results);
 }
 
-/**
- * gpk_log_refresh
- **/
 static void
 gpk_log_refresh (void)
 {
@@ -621,9 +545,6 @@ gpk_log_refresh (void)
 					      (GAsyncReadyCallback) gpk_log_get_old_transactions_cb, NULL);
 }
 
-/**
- * gpk_log_button_refresh_cb:
- **/
 static void
 gpk_log_button_refresh_cb (GtkWidget *widget, gpointer data)
 {
@@ -631,18 +552,12 @@ gpk_log_button_refresh_cb (GtkWidget *widget, gpointer data)
 	gpk_log_refresh ();
 }
 
-/**
- * gpk_log_button_filter_cb:
- **/
 static void
 gpk_log_button_filter_cb (GtkWidget *widget2, gpointer data)
 {
 	gpk_log_refilter ();
 }
 
-/**
- * gpk_log_entry_filter_cb:
- **/
 static gboolean
 gpk_log_entry_filter_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_data)
 {
@@ -650,18 +565,12 @@ gpk_log_entry_filter_cb (GtkWidget *widget, GdkEventKey *event, gpointer user_da
 	return FALSE;
 }
 
-/**
- * gpk_log_button_close_cb:
- **/
 static void
 gpk_log_button_close_cb (GtkWidget *widget, GtkApplication *application)
 {
 	g_application_release (G_APPLICATION (application));
 }
 
-/**
- * gpk_log_activate_cb:
- **/
 static void
 gpk_log_activate_cb (GtkApplication *application, gpointer user_data)
 {
@@ -670,16 +579,10 @@ gpk_log_activate_cb (GtkApplication *application, gpointer user_data)
 	gtk_window_present (window);
 }
 
-/**
- * gpk_log_startup_cb:
- **/
 static void
 gpk_log_startup_cb (GtkApplication *application, gpointer user_data)
 {
-	gboolean ret;
-	GError *error = NULL;
-	GSettings *settings;
-	GtkEntryCompletion *completion;
+	g_autoptr(GError) error = NULL;
 	GtkTreeSelection *selection;
 	GtkWidget *widget;
 	GtkWindow *window;
@@ -695,7 +598,6 @@ gpk_log_startup_cb (GtkApplication *application, gpointer user_data)
 	retval = gtk_builder_add_from_file (builder, GPK_DATA "/gpk-log.ui", &error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
-		g_error_free (error);
 		goto out;
 	}
 
@@ -728,19 +630,7 @@ gpk_log_startup_cb (GtkApplication *application, gpointer user_data)
 	g_signal_connect (widget, "activate", G_CALLBACK (gpk_log_button_filter_cb), NULL);
 
 	/* autocompletion can be turned off as it's slow */
-	settings = g_settings_new (GPK_SETTINGS_SCHEMA);
-	ret = g_settings_get_boolean (settings, GPK_SETTINGS_AUTOCOMPLETE);
-	if (ret) {
-		/* create the completion object */
-		completion = gpk_package_entry_completion_new ();
-		widget = GTK_WIDGET (gtk_builder_get_object (builder, "entry_package"));
-		gtk_entry_set_completion (GTK_ENTRY (widget), completion);
-		g_object_unref (completion);
-	} else {
-		/* use search as you type */
-		g_signal_connect (widget, "key-release-event", G_CALLBACK (gpk_log_entry_filter_cb), NULL);
-	}
-	g_object_unref (settings);
+	g_signal_connect (widget, "key-release-event", G_CALLBACK (gpk_log_entry_filter_cb), NULL);
 
 	/* create list stores */
 	list_store = gtk_list_store_new (GPK_LOG_COLUMN_LAST, G_TYPE_STRING, G_TYPE_STRING,
@@ -784,16 +674,13 @@ out:
 		g_ptr_array_unref (transactions);
 }
 
-/**
- * main:
- **/
 int
 main (int argc, char *argv[])
 {
 	gboolean ret;
 	gint status = 1;
 	GOptionContext *context;
-	GtkApplication *application = NULL;
+	g_autoptr(GtkApplication) application = NULL;
 
 	const GOptionEntry options[] = {
 		{ "filter", 'f', 0, G_OPTION_ARG_STRING, &filter,
@@ -842,7 +729,5 @@ main (int argc, char *argv[])
 out:
 	if (builder != NULL)
 		g_object_unref (builder);
-	if (application != NULL)
-		g_object_unref (application);
 	return status;
 }
