@@ -33,11 +33,6 @@ static void     gpk_task_finalize	(GObject     *object);
 
 #define GPK_TASK_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPK_TYPE_TASK, GpkTaskPrivate))
 
-/**
- * GpkTaskPrivate:
- *
- * Private #GpkTask data
- **/
 struct _GpkTaskPrivate
 {
 	gpointer		 user_data;
@@ -53,9 +48,6 @@ struct _GpkTaskPrivate
 
 G_DEFINE_TYPE (GpkTask, gpk_task, PK_TYPE_TASK)
 
-/**
- * gpk_task_set_parent_window:
- **/
 gboolean
 gpk_task_set_parent_window (GpkTask *task, GtkWindow *parent_window)
 {
@@ -65,9 +57,6 @@ gpk_task_set_parent_window (GpkTask *task, GtkWindow *parent_window)
 	return TRUE;
 }
 
-/**
- * gpk_task_button_accept_cb:
- **/
 static void
 gpk_task_button_accept_cb (GtkWidget *widget, GpkTask *task)
 {
@@ -77,9 +66,6 @@ gpk_task_button_accept_cb (GtkWidget *widget, GpkTask *task)
 	task->priv->current_window = NULL;
 }
 
-/**
- * gpk_task_button_decline_cb:
- **/
 static void
 gpk_task_button_decline_cb (GtkWidget *widget, GpkTask *task)
 {
@@ -89,9 +75,6 @@ gpk_task_button_decline_cb (GtkWidget *widget, GpkTask *task)
 	task->priv->current_window = NULL;
 }
 
-/**
- * gpk_task_dialog_response_cb:
- **/
 static void
 gpk_task_dialog_response_cb (GtkDialog *dialog, gint response_id, GpkTask *task)
 {
@@ -103,14 +86,11 @@ gpk_task_dialog_response_cb (GtkDialog *dialog, gint response_id, GpkTask *task)
 	gpk_task_button_decline_cb (GTK_WIDGET(dialog), task);
 }
 
-/**
- * gpk_task_untrusted_question:
- **/
 static void
 gpk_task_untrusted_question (PkTask *task, guint request, PkResults *results)
 {
 	GtkWidget *widget;
-	gchar *message;
+	g_autofree gchar *message = NULL;
 	PkRoleEnum role;
 	GpkTaskPrivate *priv = GPK_TASK(task)->priv;
 
@@ -146,7 +126,6 @@ gpk_task_untrusted_question (PkTask *task, guint request, PkResults *results)
 	}
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder_untrusted, "label_message"));
 	gtk_label_set_markup (GTK_LABEL (widget), message);
-	g_free (message);
 
 	/* show window */
 	priv->current_window = GTK_WINDOW(gtk_builder_get_object (priv->builder_untrusted, "dialog_error"));
@@ -160,20 +139,17 @@ gpk_task_untrusted_question (PkTask *task, guint request, PkResults *results)
 	gtk_widget_show (GTK_WIDGET(priv->current_window));
 }
 
-/**
- * gpk_task_key_question:
- **/
 static void
 gpk_task_key_question (PkTask *task, guint request, PkResults *results)
 {
-	GPtrArray *array;
+	g_autoptr(GPtrArray) array = NULL;
 	GtkWidget *widget;
-	gchar *printable = NULL;
-	gchar *package_id = NULL;
-	gchar *repository_name = NULL;
-	gchar *key_url = NULL;
-	gchar *key_userid = NULL;
-	gchar *key_id = NULL;
+	g_autofree gchar *printable = NULL;
+	g_autofree gchar *package_id = NULL;
+	g_autofree gchar *repository_name = NULL;
+	g_autofree gchar *key_url = NULL;
+	g_autofree gchar *key_userid = NULL;
+	g_autofree gchar *key_id = NULL;
 	PkRepoSignatureRequired *item;
 	GpkTaskPrivate *priv = GPK_TASK(task)->priv;
 
@@ -184,7 +160,7 @@ gpk_task_key_question (PkTask *task, guint request, PkResults *results)
 	array = pk_results_get_repo_signature_required_array (results);
 	if (array->len != 1) {
 		g_warning ("array length %i, aborting", array->len);
-		goto out;
+		return;
 	}
 
 	/* only one item supported */
@@ -221,31 +197,20 @@ gpk_task_key_question (PkTask *task, guint request, PkResults *results)
 	}
 	priv->help_id = "gpg-signature";
 	gtk_widget_show (GTK_WIDGET(priv->current_window));
-out:
-	g_free (printable);
-	g_free (package_id);
-	g_free (repository_name);
-	g_free (key_url);
-	g_free (key_userid);
-	g_free (key_id);
-	g_ptr_array_unref (array);
 }
 
-/**
- * gpk_task_eula_question:
- **/
 static void
 gpk_task_eula_question (PkTask *task, guint request, PkResults *results)
 {
-	GPtrArray *array;
+	g_autoptr(GPtrArray) array = NULL;
 	GtkWidget *widget;
-	GtkTextBuffer *buffer;
-	gchar *printable = NULL;
-	gchar **split = NULL;
+	g_autoptr(GtkTextBuffer) buffer = NULL;
+	g_autofree gchar *printable = NULL;
+	g_auto(GStrv) split = NULL;
 	PkEulaRequired *item;
-	gchar *package_id = NULL;
-	gchar *vendor_name = NULL;
-	gchar *license_agreement = NULL;
+	g_autofree gchar *package_id = NULL;
+	g_autofree gchar *vendor_name = NULL;
+	g_autofree gchar *license_agreement = NULL;
 	GpkTaskPrivate *priv = GPK_TASK(task)->priv;
 
 	/* save the current request */
@@ -255,7 +220,7 @@ gpk_task_eula_question (PkTask *task, guint request, PkResults *results)
 	array = pk_results_get_eula_required_array (results);
 	if (array->len != 1) {
 		g_warning ("array length %i, aborting", array->len);
-		goto out;
+		return;
 	}
 
 	/* only one item supported */
@@ -291,27 +256,15 @@ gpk_task_eula_question (PkTask *task, guint request, PkResults *results)
 	}
 	priv->help_id = "eula";
 	gtk_widget_show (GTK_WIDGET(priv->current_window));
-
-	g_object_unref (buffer);
-out:
-	g_free (printable);
-	g_free (package_id);
-	g_free (vendor_name);
-	g_free (license_agreement);
-	g_strfreev (split);
-	g_ptr_array_unref (array);
 }
 
-/**
- * gpk_task_media_change_question:
- **/
 static void
 gpk_task_media_change_question (PkTask *task, guint request, PkResults *results)
 {
-	GPtrArray *array;
+	g_autoptr(GPtrArray) array = NULL;
 	PkMediaChangeRequired *item;
 	const gchar *name;
-	gchar *message = NULL;
+	g_autofree gchar *message = NULL;
 	gchar *media_id;
 	PkMediaTypeEnum media_type;
 	gchar *media_text;
@@ -324,7 +277,7 @@ gpk_task_media_change_question (PkTask *task, guint request, PkResults *results)
 	array = pk_results_get_media_change_required_array (results);
 	if (array->len != 1) {
 		g_warning ("array length %i, aborting", array->len);
-		goto out;
+		return;
 	}
 
 	/* only one item supported */
@@ -353,24 +306,18 @@ gpk_task_media_change_question (PkTask *task, guint request, PkResults *results)
 
 	g_signal_connect (priv->current_window, "response", G_CALLBACK (gpk_task_dialog_response_cb), task);
 	gtk_widget_show_all (GTK_WIDGET(priv->current_window));
-out:
-	g_free (message);
-	g_ptr_array_unref (array);
 }
 
-/**
- * gpk_task_add_dialog_deps_section:
- **/
 static void
 gpk_task_add_dialog_deps_section (PkTask *task,
 				  GtkNotebook *tabbed_widget,
 				  PkPackageSack *sack,
 				  PkInfoEnum info)
 {
-	PkPackageSack *sack_tmp;
-	GPtrArray *array_tmp = NULL;
+	g_autoptr(PkPackageSack) sack_tmp = NULL;
+	g_autoptr(GPtrArray) array_tmp = NULL;
 	gboolean ret;
-	GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 	guint64 size;
 	const gchar *title;
 	GtkWidget *tab_page;
@@ -379,7 +326,7 @@ gpk_task_add_dialog_deps_section (PkTask *task,
 	sack_tmp = pk_package_sack_filter_by_info (sack, info);
 	if (pk_package_sack_get_size (sack_tmp) == 0) {
 		g_debug ("no packages with %s", pk_info_enum_to_string (info));
-		goto out;
+		return;
 	}
 
 	tab_page = gtk_box_new (GTK_ORIENTATION_VERTICAL, 6);
@@ -428,7 +375,6 @@ gpk_task_add_dialog_deps_section (PkTask *task,
 	ret = pk_package_sack_get_details (sack_tmp, NULL, &error);
 	if (!ret) {
 		g_warning ("failed to get details about packages: %s", error->message);
-		g_error_free (error);
 	}
 	size = pk_package_sack_get_total_bytes (sack_tmp);
 
@@ -437,23 +383,16 @@ gpk_task_add_dialog_deps_section (PkTask *task,
 	gpk_dialog_tabbed_download_size_widget (tab_page, title, size);
 	gpk_dialog_tabbed_package_list_widget (tab_page, array_tmp);
 	gtk_notebook_append_page (tabbed_widget, tab_page, tab_label);
-out:
-	if (array_tmp != NULL)
-		g_ptr_array_unref (array_tmp);
-	g_object_unref (sack_tmp);
 }
 
-/**
- * gpk_task_simulate_question:
- **/
 static void
 gpk_task_simulate_question (PkTask *task, guint request, PkResults *results)
 {
 	gboolean ret;
-	GPtrArray *array = NULL;
+	g_autoptr(GPtrArray) array = NULL;
 	GpkTaskPrivate *priv = GPK_TASK(task)->priv;
 	PkRoleEnum role;
-	PkPackageSack *sack = NULL;
+	g_autoptr(PkPackageSack) sack = NULL;
 	guint inputs;
 	const gchar *title;
 	const gchar *message = NULL;
@@ -477,7 +416,7 @@ gpk_task_simulate_question (PkTask *task, guint request, PkResults *results)
 		if (!ret) {
 			g_debug ("we've said we don't want the dep dialog");
 			pk_task_user_accepted (PK_TASK(task), priv->request);
-			goto out;
+			return;
 		}
 	}
 
@@ -556,30 +495,21 @@ gpk_task_simulate_question (PkTask *task, guint request, PkResults *results)
 
 	g_signal_connect (priv->current_window, "response", G_CALLBACK (gpk_task_dialog_response_cb), task);
 	gtk_widget_show_all (GTK_WIDGET(priv->current_window));
-out:
-	if (sack != NULL)
-		g_object_unref (sack);
-	if (array != NULL)
-		g_ptr_array_unref (array);
 }
 
-/**
- * gpk_task_setup_dialog_untrusted:
- **/
 static void
 gpk_task_setup_dialog_untrusted (GpkTask *task)
 {
 	GtkWidget *widget;
 	GtkWidget *button;
 	guint retval;
-	GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 
 	/* get UI */
 	task->priv->builder_untrusted = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (task->priv->builder_untrusted, GPK_DATA "/gpk-error.ui", &error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
-		g_error_free (error);
 	}
 
 	/* connect up default actions */
@@ -587,7 +517,6 @@ gpk_task_setup_dialog_untrusted (GpkTask *task)
 	g_signal_connect (widget, "delete_event", G_CALLBACK (gpk_task_button_decline_cb), task);
 
 	/* set icon name */
-	widget = GTK_WIDGET (gtk_builder_get_object (task->priv->builder_untrusted, "dialog_error"));
 	gtk_window_set_icon_name (GTK_WINDOW(widget), GPK_ICON_SOFTWARE_INSTALLER);
 
 	/* connect up buttons */
@@ -605,29 +534,24 @@ gpk_task_setup_dialog_untrusted (GpkTask *task)
 	/* TRANSLATORS: button tooltip */
 	gtk_widget_set_tooltip_text (button, _("Force installing package"));
 
-	/* add to box */
+	/* add to dialog */
 	widget = GTK_WIDGET (gtk_builder_get_object (task->priv->builder_untrusted, "dialog_error"));
-	widget = gtk_dialog_get_action_area (GTK_DIALOG(widget));
-	gtk_box_pack_start (GTK_BOX (widget), button, FALSE, FALSE, 0);
+	gtk_dialog_add_action_widget (GTK_DIALOG (widget), button, GTK_RESPONSE_NONE);
 	gtk_widget_show (button);
 }
 
-/**
- * gpk_task_setup_dialog_signature:
- **/
 static void
 gpk_task_setup_dialog_signature (GpkTask *task)
 {
 	GtkWidget *widget;
 	guint retval;
-	GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 
 	/* get UI */
 	task->priv->builder_signature = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (task->priv->builder_signature, GPK_DATA "/gpk-signature.ui", &error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
-		g_error_free (error);
 	}
 
 	/* connect up default actions */
@@ -645,22 +569,18 @@ gpk_task_setup_dialog_signature (GpkTask *task)
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_task_button_decline_cb), task);
 }
 
-/**
- * gpk_task_setup_dialog_eula:
- **/
 static void
 gpk_task_setup_dialog_eula (GpkTask *task)
 {
 	GtkWidget *widget;
 	guint retval;
-	GError *error = NULL;
+	g_autoptr(GError) error = NULL;
 
 	/* get UI */
 	task->priv->builder_eula = gtk_builder_new ();
 	retval = gtk_builder_add_from_file (task->priv->builder_eula, GPK_DATA "/gpk-eula.ui", &error);
 	if (retval == 0) {
 		g_warning ("failed to load ui: %s", error->message);
-		g_error_free (error);
 	}
 
 	/* connect up default actions */
@@ -678,9 +598,6 @@ gpk_task_setup_dialog_eula (GpkTask *task)
 	g_signal_connect (widget, "clicked", G_CALLBACK (gpk_task_button_decline_cb), task);
 }
 
-/**
- * gpk_task_class_init:
- **/
 static void
 gpk_task_class_init (GpkTaskClass *klass)
 {
@@ -697,10 +614,6 @@ gpk_task_class_init (GpkTaskClass *klass)
 	g_type_class_add_private (klass, sizeof (GpkTaskPrivate));
 }
 
-/**
- * gpk_task_init:
- * @task: This class instance
- **/
 static void
 gpk_task_init (GpkTask *task)
 {
@@ -716,10 +629,6 @@ gpk_task_init (GpkTask *task)
 	gpk_task_setup_dialog_signature (task);
 }
 
-/**
- * gpk_task_finalize:
- * @object: The object to finalize
- **/
 static void
 gpk_task_finalize (GObject *object)
 {
@@ -733,11 +642,6 @@ gpk_task_finalize (GObject *object)
 	G_OBJECT_CLASS (gpk_task_parent_class)->finalize (object);
 }
 
-/**
- * gpk_task_new:
- *
- * Return value: a new GpkTask object.
- **/
 GpkTask *
 gpk_task_new (void)
 {
